import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/userManagement',
    children: [
      {
        path: 'userManagement',
        name: 'userManagement',
        component: () => import('@/views/userManagement/userManagement'),
        meta: { title: '客户管理', icon: 'dashboard' }
      },
      {
        path: 'userEdit',
        name: 'userEdit',
        hidden: true,
        component: () => import('@/views/kehuEdit/index'),
        meta: { title: '客户编辑', icon: 'dashboard', breadcrumb: false }
      },]
  },



  {
    path: '/operate',
    component: Layout,
    redirect: '/operate/operateUserManagement',
    name: 'operate',
    // meta: { title: 'operate', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'operateUserManagement',
        name: 'operateUserManagement',
        component: () => import('@/views/operateUserManage/OperateUserManagement'),
        meta: { title: '客服管理', icon: 'table' }
      },

    ]
  },
  {
    path: '/hr',
    component: Layout,
    redirect: '/hr/hrManagement',
    name: 'hr',
    // meta: { title: 'operate', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'hrManagement',
        name: 'hrManagement',
        component: () => import('@/views/hrManagement/hrManagement'),
        meta: { title: '医生管理', icon: 'tree' }
      },

    ]
  },
  {
    path: '/order',
    component: Layout,
    redirect: '/order/orderManagement',
    name: 'order',
    // meta: { title: 'operate', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'orderManagement',
        name: 'orderManagement',
        component: () => import('@/views/orderManagement/orderManagement'),
        meta: { title: '订单管理', icon: 'form' }
      }

    ]
  },



  // { path: '*', redirect: '/404', hidden: true }
  // { path: '*', redirect: '/404', hidden: true }

  { path: '*', redirect: '/404', hidden: true }

]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
